==> content_snapshot-3.0.0.tar.gz: content_snapshot/src/Normalizer/PasswordFieldItemNormalizer.php <==
<?php

/**
 * @file
 */

namespace Drupal\content_snapshot\Normalizer;

use Drupal\serialization\Normalizer\FieldItemNormalizer;
use Drupal\content_snapshot\Encoder\YamlEncoder;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Field\Plugin\Field\FieldType\PasswordItem;
use Drupal\pathauto\PathautoGeneratorInterface;

/**
 * Class PasswordFieldItemNormalizer.
 */
class PasswordFieldItemNormalizer extends FieldItemNormalizer {

  use ContentSnapshotNormalizerContextTrait;

  protected $format = YamlEncoder::FORMAT;

  protected $supportedInterfaceOrClass = PasswordItem::class;

  /** @var \Drupal\pathauto\PathautoGeneratorInterface|null */
  private $pathautoGenerator;

  /**
   * PathItemNormalizer constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * @param \Drupal\pathauto\PathautoGeneratorInterface $pathautoGenerator
   */
  public function setPathautoGenerator(PathautoGeneratorInterface $pathautoGenerator) {
    $this->pathautoGenerator = $pathautoGenerator;
  }

  /**
   * {@inheritdoc}
   *
   * @param $field \Drupal\Core\Field\FieldItemInterface
   */
  public function normalize($field, $format = NULL, array $context = []): array|string|int|float|bool|\ArrayObject|NULL {

    $this->validateContext($context);

    $attributes = parent::normalize($field, $format, $context);
    $attributes['pre_hashed'] = TRUE;
    unset($attributes['existing']);

    return $attributes;
  }

  /**
   * {@inheritDoc}
   */
  public function denormalize($data, $class, $format = NULL, array $context = []): mixed {

    $this->validateContext($context);

    return parent::denormalize($data, $class, $format, $context);
  }

}

==> content_snapshot-3.0.1.tar.gz: content_snapshot/src/Normalizer/PasswordFieldItemNormalizer.php <==
<?php

/**
 * @file
 */

namespace Drupal\content_snapshot\Normalizer;

use Drupal\content_snapshot\Encoder\YamlEncoderInterface;
use Drupal\serialization\Normalizer\FieldItemNormalizer;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Field\Plugin\Field\FieldType\PasswordItem;
use Drupal\pathauto\PathautoGeneratorInterface;

/**
 * Class PasswordFieldItemNormalizer.
 */
class PasswordFieldItemNormalizer extends FieldItemNormalizer {

  use ContentSnapshotNormalizerContextTrait;

  protected $format = YamlEncoderInterface::FORMAT;

  protected $supportedInterfaceOrClass = PasswordItem::class;

  /** @var \Drupal\pathauto\PathautoGeneratorInterface|null */
  private $pathautoGenerator;

  /**
   * PathItemNormalizer constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   */
  public function __construct(EntityTypeManagerInterface $entityTypeManager) {
    $this->entityTypeManager = $entityTypeManager;
  }

  /**
   * @param \Drupal\pathauto\PathautoGeneratorInterface $pathautoGenerator
   */
  public function setPathautoGenerator(PathautoGeneratorInterface $pathautoGenerator) {
    $this->pathautoGenerator = $pathautoGenerator;
  }

  /**
   * {@inheritdoc}
   *
   * @param $field \Drupal\Core\Field\FieldItemInterface
   */
  public function normalize($field, $format = NULL, array $context = []): array|string|int|float|bool|\ArrayObject|NULL {

    $this->validateContext($context);

    $attributes = parent::normalize($field, $format, $context);
    $attributes['pre_hashed'] = TRUE;
    unset($attributes['existing']);

    return $attributes;
  }

  /**
   * {@inheritDoc}
   */
  public function denormalize($data, $class, $format = NULL, array $context = []): mixed {

    $this->validateContext($context);

    return parent::denormalize($data, $class, $format, $context);
  }

}
